import React, { useState, useEffect } from 'react';
import { BrowserRouter as Router, Routes, Route, Link } from 'react-router-dom';
import { 
  Linkedin, 
  Package, 
  Menu, 
  X,
  ArrowRight
} from 'lucide-react';

// Import existing pages
import Home from './pages/Home';
import Features from './pages/Features';
import About from './pages/About';
import Solutions from './pages/Solutions';
import Contact from './pages/Contact';
import Track from './pages/Track';
import Deliveries from './pages/Deliveries';
import RouteOptimization from './pages/RouteOptimization';
import DriverApp from './pages/DriverApp';
import DSPs from './pages/DSPs';
import FAQ from './pages/FAQ';
import Cities from './pages/Cities';
import PrivacyPolicy from './pages/PrivacyPolicy';
import ProofOfDelivery from './pages/ProofOfDelivery';
import Resources from './pages/Resources';
import Terms from './pages/Terms';
import NotFound from './pages/NotFound';
import Integrations from './pages/Integrations';
import RecipientNotifications from './pages/RecipientNotifications';
import Sitemap from './pages/Sitemap';
import LogisticsOS from './pages/LogisticsOS';
import Startups from './pages/Startups';

// Import new SEO-focused landing pages
import LastMileDeliveryManagement from './pages/landing/LastMileDeliveryManagement';
import ElectronicProofOfDelivery from './pages/landing/ElectronicProofOfDelivery';
import AIRouteOptimization from './pages/landing/AIRouteOptimization';
import LastMileDeliverySolutions from './pages/landing/LastMileDeliverySolutions';
import DeliveryTracking from './pages/landing/DeliveryTracking';
import CourierSoftware from './pages/landing/CourierSoftware';
import TransportationManagement from './pages/landing/TransportationManagement';
import DriverMobileApp from './pages/landing/DriverMobileApp';

// Import all resource pages
import AIOperatingSystemBlog from './pages/resources/ai-automated-operating-system';
import FutureLastMileDeliverySaaS from './pages/resources/future-last-mile-delivery-saas';
import ClientTestimonials from './pages/resources/client-testimonials';
import GrowLondonGlobal from './pages/resources/grow-london-global';
import FleetNewsAwards from './pages/resources/fleet-news-awards';
import ClimateTeachAward from './pages/resources/climate-tech-award';
import DeliveryVolumePrediction from './pages/resources/delivery-volume-prediction';
import AdaptiveIntelligence from './pages/resources/adaptive-intelligence';
import LastMileSecret from './pages/resources/last-mile-secret';
import LastMileEfficiency from './pages/resources/last-mile-efficiency';
import StartupsTop100 from './pages/resources/startups-top-100';
import AIReshapingEcommerce from './pages/resources/ai-reshaping-ecommerce';
import TransformingLastMile2030 from './pages/resources/transforming-last-mile-2030';
import FutureTrendsLastMile from './pages/resources/future-trends-last-mile';
import RouteOptimizationGuide from './pages/resources/route-optimization-guide';
import RouteOptimizationSaaS from './pages/resources/route-optimization-saas';
import AIPoweredCourier from './pages/resources/ai-powered-courier';
import FastRouteOptimization from './pages/resources/fast-route-optimization';
import OptimizingLastMileDelivery from './pages/resources/optimizing-last-mile-delivery';
import AIInLogistics from './pages/resources/ai-in-logistics';
import UltimateGuideAIRouteOptimisation from './pages/resources/ultimate-guide-ai-route-optimisation';
import MaximizingEfficiencyRoutePlanning from './pages/resources/maximizing-efficiency-route-planning';
import UrbanLogisticsReimagined from './pages/resources/urban-logistics-reimagined';
import DataToDelivery from './pages/resources/data-to-delivery';
import EcommerceRouteOptimization from './pages/resources/ecommerce-route-optimization';
import LastMileDeliveryChallenges from './pages/resources/last-mile-delivery-challenges';
import SustainableLogistics from './pages/resources/sustainable-logistics';
import RouteOptimizationTrends2025 from './pages/resources/route-optimization-trends-2025';
import AIMachineLearningLastMile from './pages/resources/ai-machine-learning-last-mile';
import RouteOptimizationGuideStepByStep from './pages/resources/route-optimization-step-by-step';
import BestLogisticsSoftware2025 from './pages/resources/best-logistics-software-2025';
import OptimizeSupplyChainLogisticsSoftware from './pages/resources/optimize-supply-chain-logistics-software';
import StreamlineDeliveriesLogisticsSoftware from './pages/resources/streamline-deliveries-logistics-software';
import BestRouteOptimizationApp from './pages/resources/best-route-optimization-app';
import WhatIsRouteOptimizationSoftware from './pages/resources/what-is-route-optimization-software';
import SimplifyDeliveriesRoutePlanning from './pages/resources/simplify-deliveries-route-planning';
import OptimizeFleetRoutePlanning from './pages/resources/optimize-fleet-route-planning';
import RouteMonitoringVisibility from './pages/resources/route-monitoring-visibility';
import DeliveryRoutingSoftware from './pages/resources/delivery-routing-software';
import BoostEfficiencyRouteOptimization from './pages/resources/boost-efficiency-route-optimization';
import NumberOneRouteOptimizationSoftware from './pages/resources/number-one-route-optimization-software';
import SupplyChainLogisticsManagement from './pages/resources/supply-chain-logistics-management';
import AIPoweredPlatform from './pages/resources/ai-powered-platform';
import DecodingLastMile from './pages/resources/decoding-last-mile';

function App() {
  const [isScrolled, setIsScrolled] = useState(false);
  const [isMobileMenuOpen, setIsMobileMenuOpen] = useState(false);

  useEffect(() => {
    const handleScroll = () => {
      setIsScrolled(window.scrollY > 10);
    };

    window.addEventListener('scroll', handleScroll);
    return () => window.removeEventListener('scroll', handleScroll);
  }, []);

  useEffect(() => {
    if (isMobileMenuOpen) {
      document.body.style.overflow = 'hidden';
    } else {
      document.body.style.overflow = 'unset';
    }
  }, [isMobileMenuOpen]);

  return (
    <Router>
      <div className="min-h-screen bg-white">
        {/* Mobile Navigation Menu */}
        <div 
          className={`fixed inset-0 bg-black/50 z-50 transition-opacity duration-300 md:hidden ${
            isMobileMenuOpen ? 'opacity-100' : 'opacity-0 pointer-events-none'
          }`}
          onClick={() => setIsMobileMenuOpen(false)}
        >
          <div 
            className={`absolute right-0 top-0 h-full w-64 bg-white shadow-xl transform transition-transform duration-300 ${
              isMobileMenuOpen ? 'translate-x-0' : 'translate-x-full'
            }`}
            onClick={e => e.stopPropagation()}
          >
            <div className="p-6">
              <button 
                onClick={() => setIsMobileMenuOpen(false)}
                className="absolute top-4 right-4 p-2 hover:bg-gray-100 rounded-lg transition-colors duration-200"
              >
                <X className="w-6 h-6 text-gray-600" />
              </button>
              
              <div className="mt-16 flex flex-col space-y-6">
                <Link 
                  to="/"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="text-lg font-medium text-gray-800 hover:text-[#2f1c8c] transition-colors duration-200"
                >
                  Home
                </Link>
                <Link 
                  to="/solutions"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="text-lg font-medium text-gray-800 hover:text-[#2f1c8c] transition-colors duration-200"
                >
                  Solutions
                </Link>
                <Link 
                  to="/deliveries"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="text-lg font-medium text-gray-800 hover:text-[#2f1c8c] transition-colors duration-200"
                >
                  Deliveries
                </Link>
                <Link 
                  to="/features"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="text-lg font-medium text-gray-800 hover:text-[#2f1c8c] transition-colors duration-200"
                >
                  Features
                </Link>
                <Link 
                  to="/dsps"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="text-lg font-medium text-gray-800 hover:text-[#2f1c8c] transition-colors duration-200"
                >
                  DSPs
                </Link>
                <Link 
                  to="/about"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="text-lg font-medium text-gray-800 hover:text-[#2f1c8c] transition-colors duration-200"
                >
                  About
                </Link>
                <Link 
                  to="/resources"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="text-lg font-medium text-gray-800 hover:text-[#2f1c8c] transition-colors duration-200"
                >
                  Resources
                </Link>
                <Link 
                  to="/contact"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="text-lg font-medium text-gray-800 hover:text-[#2f1c8c] transition-colors duration-200"
                >
                  Contact
                </Link>
              </div>

              <div className="absolute bottom-8 inset-x-6">
                <Link 
                  to="/track"
                  onClick={() => setIsMobileMenuOpen(false)}
                  className="flex items-center justify-center space-x-2 w-full bg-[#2f1c8c] text-white px-4 py-3 rounded-lg font-medium hover:bg-[#2f1c8c]/90 transition-all duration-300"
                >
                  <Package className="w-5 h-5" />
                  <span>Track Parcel</span>
                </Link>
              </div>
            </div>
          </div>
        </div>

        {/* Navigation */}
        <nav 
          className={`fixed w-full z-40 transition-all duration-300 ${
            isScrolled 
              ? 'bg-white/95 backdrop-blur-sm shadow-md py-3' 
              : 'bg-[#2f1c8c] py-4'
          }`}
        >
          <div className="container mx-auto px-4 md:px-6">
            <div className="flex items-center justify-between">
              {/* Mobile menu button */}
              <button 
                className="md:hidden p-2 hover:bg-white/10 rounded-lg transition-colors duration-200"
                onClick={() => setIsMobileMenuOpen(true)}
                aria-label="Open menu"
              >
                <Menu className={`w-6 h-6 ${isScrolled ? 'text-gray-800' : 'text-white'}`} />
              </button>

              <Link to="/" className="hover-scale">
                <svg 
                  className={`w-16 h-auto transition-all duration-300 ${
                    isScrolled ? 'fill-[#2f1c8c]' : 'fill-white'
                  }`} 
                  viewBox="0 0 179.89 139.36" 
                  xmlns="http://www.w3.org/2000/svg"
                >
                  <g>
                    <path d="M29.15,69.73v.68h20.34v24.23H30v44.72H0V66.34c0-19.66,13.73-28.81,34.91-28.81,4.91,0,10,.51,15.59,1.36v20.67c-2.71-.51-5.93-.68-8.3-.68-8.98,0-13.05,3.39-13.05,10.85Z"/>
                    <path d="M56.31,139.36V70.2h29.44v69.16h-29.44Z"/>
                    <path d="M179.89,106.63v32.73h-29.61v-29.41c0-9.81-4.82-15.14-13.47-15.14-9.65,0-12.97,5.66-12.97,15.64v28.91h-29.44V70.2h27.11l1,9.98c6.49-7.65,13.14-11.64,23.95-11.64,22.79,0,33.43,15.14,33.43,38.09Z"/>
                    <path d="M88.73,0h0c-17.91,0-32.43,14.52-32.43,32.43v32.43h32.43c17.91,0,32.43-14.52,32.43-32.43h0C121.16,14.52,106.64,0,88.73,0Zm0,46.88c-7.98,0-14.45-6.47-14.45-14.45s6.47-14.45,14.45-14.45,14.45,6.47,14.45,14.45-6.47,14.45-14.45,14.45Z"/>
                  </g>
                </svg>
              </Link>

              {/* Desktop Navigation Links */}
              <div className="hidden md:flex items-center space-x-8">
                <Link 
                  to="/solutions" 
                  className={`text-sm font-medium transition-all duration-300 hover:scale-105 transform border-b-2 border-transparent hover:border-current ${
                    isScrolled ? 'text-gray-800 hover:text-[#2f1c8c]' : 'text-white/90 hover:text-white'
                  }`}
                >
                  Solutions
                </Link>
                <Link 
                  to="/deliveries" 
                  className={`text-sm font-medium transition-all duration-300 hover:scale-105 transform border-b-2 border-transparent hover:border-current ${
                    isScrolled ? 'text-gray-800 hover:text-[#2f1c8c]' : 'text-white/90 hover:text-white'
                  }`}
                >
                  Deliveries
                </Link>
                <Link 
                  to="/features" 
                  className={`text-sm font-medium transition-all duration-300 hover:scale-105 transform border-b-2 border-transparent hover:border-current ${
                    isScrolled ? 'text-gray-800 hover:text-[#2f1c8c]' : 'text-white/90 hover:text-white'
                  }`}
                >
                  Features
                </Link>
                <Link 
                  to="/dsps" 
                  className={`text-sm font-medium transition-all duration-300 hover:scale-105 transform border-b-2 border-transparent hover:border-current ${
                    isScrolled ? 'text-gray-800 hover:text-[#2f1c8c]' : 'text-white/90 hover:text-white'
                  }`}
                >
                  DSPs
                </Link>
                <Link 
                  to="/about" 
                  className={`text-sm font-medium transition-all duration-300 hover:scale-105 transform border-b-2 border-transparent hover:border-current ${
                    isScrolled ? 'text-gray-800 hover:text-[#2f1c8c]' : 'text-white/90 hover:text-white'
                  }`}
                >
                  About
                </Link>
                <Link 
                  to="/resources" 
                  className={`text-sm font-medium transition-all duration-300 hover:scale-105 transform border-b-2 border-transparent hover:border-current ${
                    isScrolled ? 'text-gray-800 hover:text-[#2f1c8c]' : 'text-white/90 hover:text-white'
                  }`}
                >
                  Resources
                </Link>
              </div>

              {/* Desktop Action Buttons */}
              <div className="hidden md:flex items-center space-x-4">
                <Link 
                  to="/track"
                  className={`inline-flex items-center px-5 py-2 rounded-lg text-sm font-medium transition-all duration-300 hover:shadow-lg transform hover:scale-105 ${
                    isScrolled 
                      ? 'bg-[#2f1c8c]/10 text-[#2f1c8c] hover:bg-[#2f1c8c]/20' 
                      : 'bg-white/10 text-white hover:bg-white/20'
                  }`}
                >
                  <Package className="w-4 h-4 mr-2" />
                  Track Parcel
                </Link>
                <Link 
                  to="/contact"
                  className={`px-5 py-2 rounded-lg text-sm font-medium transition-all duration-300 hover:shadow-lg transform hover:scale-105 ${
                    isScrolled 
                      ? 'bg-[#2f1c8c] text-white hover:bg-[#2f1c8c]/90' 
                      : 'bg-white text-[#2f1c8c] hover:bg-gray-100'
                  }`}
                >
                  Request a Demo
                </Link>
              </div>
            </div>
          </div>
        </nav>

        {/* Add padding to account for fixed navbar */}
        <div className="pt-20">
          <Routes>
            {/* Main Routes */}
            <Route path="/" element={<Home />} />
            <Route path="/solutions" element={<Solutions />} />
            <Route path="/features" element={<Features />} />
            <Route path="/about" element={<About />} />
            <Route path="/contact" element={<Contact />} />
            <Route path="/track" element={<Track />} />
            <Route path="/deliveries" element={<Deliveries />} />
            <Route path="/route-optimization" element={<RouteOptimization />} />
            <Route path="/driver-app" element={<DriverApp />} />
            <Route path="/dsps" element={<DSPs />} />
            <Route path="/faq" element={<FAQ />} />
            <Route path="/cities" element={<Cities />} />
            <Route path="/privacy-policy" element={<PrivacyPolicy />} />
            <Route path="/proof-of-delivery" element={<ProofOfDelivery />} />
            <Route path="/resources" element={<Resources />} />
            <Route path="/terms" element={<Terms />} />
            <Route path="/integrations" element={<Integrations />} />
            <Route path="/recipient-notifications" element={<RecipientNotifications />} />
            <Route path="/sitemap" element={<Sitemap />} />
            <Route path="/logistics-os" element={<LogisticsOS />} />
            <Route path="/startups" element={<Startups />} />

            {/* New SEO Landing Pages */}
            <Route path="/delivery-management-software" element={<LastMileDeliveryManagement />} />
            <Route path="/electronic-proof-of-delivery" element={<ElectronicProofOfDelivery />} />
            <Route path="/ai-route-optimization" element={<AIRouteOptimization />} />
            <Route path="/last-mile-delivery-solutions" element={<LastMileDeliverySolutions />} />
            <Route path="/delivery-tracking-software" element={<DeliveryTracking />} />
            <Route path="/courier-software" element={<CourierSoftware />} />
            <Route path="/transportation-management-system" element={<TransportationManagement />} />
            <Route path="/driver-mobile-app" element={<DriverMobileApp />} />

            {/* Resource Routes */}
            <Route path="/resources/future-last-mile-delivery-saas" element={<FutureLastMileDeliverySaaS />} />
            <Route path="/resources/ai-automated-operating-system" element={<AIOperatingSystemBlog />} />
            <Route path="/resources/client-testimonials" element={<ClientTestimonials />} />
            <Route path="/resources/grow-london-global" element={<GrowLondonGlobal />} />
            <Route path="/resources/fleet-news-awards" element={<FleetNewsAwards />} />
            <Route path="/resources/climate-tech-award" element={<ClimateTeachAward />} />
            <Route path="/resources/delivery-volume-prediction" element={<DeliveryVolumePrediction />} />
            <Route path="/resources/adaptive-intelligence" element={<AdaptiveIntelligence />} />
            <Route path="/resources/last-mile-secret" element={<LastMileSecret />} />
            <Route path="/resources/last-mile-efficiency" element={<LastMileEfficiency />} />
            <Route path="/resources/startups-top-100" element={<StartupsTop100 />} />
            <Route path="/resources/ai-reshaping-ecommerce" element={<AIReshapingEcommerce />} />
            <Route path="/resources/transforming-last-mile-2030" element={<TransformingLastMile2030 />} />
            <Route path="/resources/future-trends-last-mile" element={<FutureTrendsLastMile />} />
            <Route path="/resources/route-optimization-guide" element={<RouteOptimizationGuide />} />
            <Route path="/resources/route-optimization-saas" element={<RouteOptimizationSaaS />} />
            <Route path="/resources/ai-powered-courier" element={<AIPoweredCourier />} />
            <Route path="/resources/fast-route-optimization" element={<FastRouteOptimization />} />
            <Route path="/resources/optimizing-last-mile-delivery" element={<OptimizingLastMileDelivery />} />
            <Route path="/resources/ai-in-logistics" element={<AIInLogistics />} />
            <Route path="/resources/ultimate-guide-ai-route-optimisation" element={<UltimateGuideAIRouteOptimisation />} />
            <Route path="/resources/maximizing-efficiency-route-planning" element={<MaximizingEfficiencyRoutePlanning />} />
            <Route path="/resources/urban-logistics-reimagined" element={<UrbanLogisticsReimagined />} />
            <Route path="/resources/data-to-delivery" element={<DataToDelivery />} />
            <Route path="/resources/ecommerce-route-optimization" element={<EcommerceRouteOptimization />} />
            <Route path="/resources/last-mile-delivery-challenges" element={<LastMileDeliveryChallenges />} />
            <Route path="/resources/sustainable-logistics" element={<SustainableLogistics />} />
            <Route path="/resources/route-optimization-trends-2025" element={<RouteOptimizationTrends2025 />} />
            <Route path="/resources/ai-machine-learning-last-mile" element={<AIMachineLearningLastMile />} />
            <Route path="/resources/route-optimization-step-by-step" element={<RouteOptimizationGuideStepByStep />} />
            <Route path="/resources/best-logistics-software-2025" element={<BestLogisticsSoftware2025 />} />
            <Route path="/resources/optimize-supply-chain-logistics-software" element={<OptimizeSupplyChainLogisticsSoftware />} />
            <Route path="/resources/streamline-deliveries-logistics-software" element={<StreamlineDeliveriesLogisticsSoftware />} />
            <Route path="/resources/best-route-optimization-app" element={<BestRouteOptimizationApp />} />
            <Route path="/resources/what-is-route-optimization-software" element={<WhatIsRouteOptimizationSoftware />} />
            <Route path="/resources/simplify-deliveries-route-planning" element={<SimplifyDeliveriesRoutePlanning />} />
            <Route path="/resources/optimize-fleet-route-planning" element={<OptimizeFleetRoutePlanning />} />
            <Route path="/resources/route-monitoring-visibility" element={<RouteMonitoringVisibility />} />
            <Route path="/resources/delivery-routing-software" element={<DeliveryRoutingSoftware />} />
            <Route path="/resources/boost-efficiency-route-optimization" element={<BoostEfficiencyRouteOptimization />} />
            <Route path="/resources/number-one-route-optimization-software" element={<NumberOneRouteOptimizationSoftware />} />
            <Route path="/resources/supply-chain-logistics-management" element={<SupplyChainLogisticsManagement />} />
            <Route path="/resources/ai-powered-platform" element={<AIPoweredPlatform />} />
            <Route path="/resources/decoding-last-mile" element={<DecodingLastMile />} />

            {/* 404 Route */}
            <Route path="*" element={<NotFound />} />
          </Routes>

          {/* Footer */}
          <footer className="bg-gray-900 text-gray-100 py-16">
            <div className="container mx-auto px-6">
              <div className="grid md:grid-cols-3 gap-10">
                <div className="fade-in">
                  <h3 className="text-xl font-semibold mb-6 text-white">Fin Smart Logistics</h3>
                  <p className="text-gray-300 mb-6">Transforming logistics with AI-powered solutions for smarter, faster, and more sustainable deliveries.</p>
                  <div className="flex items-center space-x-4">
                    <a 
                      href="https://www.linkedin.com/company/finlogistics" 
                      target="_blank" 
                      rel="noopener noreferrer"
                      className="bg-white/10 hover:bg-white/20 p-3 rounded-full transition-colors duration-300"
                      aria-label="LinkedIn"
                    >
                      <Linkedin className="w-5 h-5 text-white" />
                    </a>
                  </div>
                </div>
                <div className="fade-in">
                  <h4 className="text-xl font-semibold mb-6 text-white">Solutions</h4>
                  <ul className="space-y-4">
                    <li>
                      <Link 
                        to="/driver-app" 
                        className="text-gray-300 hover:text-white transition-colors duration-200 flex items-center"
                      >
                        <span className="w-1.5 h-1.5 bg-[#2f1c8c] rounded-full mr-2"></span>
                        Driver & Rider App
                      </Link>
                    </li>
                    <li>
                      <Link 
                        to="/cities" 
                        className="text-gray-300 hover:text-white transition-colors duration-200 flex items-center"
                      >
                        <span className="w-1.5 h-1.5 bg-[#2f1c8c] rounded-full mr-2"></span>
                        Cities
                      </Link>
                    </li>
                    <li>
                      <Link 
                        to="/route-optimization" 
                        className="text-gray-300 hover:text-white transition-colors duration-200 flex items-center"
                      >
                        <span className="w-1.5 h-1.5 bg-[#2f1c8c] rounded-full mr-2"></span>
                        Route Optimization
                      </Link>
                    </li>
                    <li>
                      <Link 
                        to="/proof-of-delivery" 
                        className="text-gray-300 hover:text-white transition-colors duration-200 flex items-center"
                      >
                        <span className="w-1.5 h-1.5 bg-[#2f1c8c] rounded-full mr-2"></span>
                        Proof of Delivery
                      </Link>
                    </li>
                    <li>
                      <Link 
                        to="/recipient-notifications" 
                        className="text-gray-300 hover:text-white transition-colors duration-200 flex items-center"
                      >
                        <span className="w-1.5 h-1.5 bg-[#2f1c8c] rounded-full mr-2"></span>
                        Recipient Notifications
                      </Link>
                    </li>
                    <li>
                      <Link 
                        to="/logistics-os" 
                        className="text-gray-300 hover:text-white transition-colors duration-200 flex items-center"
                      >
                        <span className="w-1.5 h-1.5 bg-[#2f1c8c] rounded-full mr-2"></span>
                        Logistics Operating System
                      </Link>
                    </li>
                    <li>
                      <Link 
                        to="/startups" 
                        className="text-gray-300 hover:text-white transition-colors duration-200 flex items-center"
                      >
                        <span className="w-1.5 h-1.5 bg-[#2f1c8c] rounded-full mr-2"></span>
                        Fin for Startups
                      </Link>
                    </li>
                  </ul>
                </div>
                <div className="fade-in">
                  <h4 className="text-xl font-semibold mb-6 text-white">Company</h4>
                  <div className="grid grid-cols-2 gap-4">
                    <div>
                      <ul className="space-y-4">
                        <li>
                          <Link 
                            to="/about" 
                            className="text-gray-300 hover:text-white transition-colors duration-200 flex items-center"
                          >
                            <span className="w-1.5 h-1.5 bg-[#2f1c8c] rounded-full mr-2"></span>
                            About Us
                          </Link>
                        </li>
                        <li>
                          <Link 
                            to="/faq" 
                            className="text-gray-300 hover:text-white transition-colors duration-200 flex items-center"
                          >
                            <span className="w-1.5 h-1.5 bg-[#2f1c8c] rounded-full mr-2"></span>
                            FAQ
                          </Link>
                        </li>
                        <li>
                          <Link 
                            to="/privacy-policy" 
                            className="text-gray-300 hover:text-white transition-colors duration-200 flex items-center"
                          >
                            <span className="w-1.5 h-1.5 bg-[#2f1c8c] rounded-full mr-2"></span>
                            Privacy Policy
                          </Link>
                        </li>
                        <li>
                          <Link 
                            to="/contact" 
                            className="text-gray-300 hover:text-white transition-colors duration-200 flex items-center"
                          >
                            <span className="w-1.5 h-1.5 bg-[#2f1c8c] rounded-full mr-2"></span>
                            Contact
                          </Link>
                        </li>
                      </ul>
                    </div>
                    <div>
                      <ul className="space-y-4">
                        <li>
                          <Link 
                            to="/resources" 
                            className="text-gray-300 hover:text-white transition-colors duration-200 flex items-center"
                          >
                            <span className="w-1.5 h-1.5 bg-[#2f1c8c] rounded-full mr-2"></span>
                            Resources
                          </Link>
                        </li>
                        <li>
                          <a 
                            href="https://www.linkedin.com/company/finlogistics/jobs" 
                            target="_blank" 
                            rel="noopener noreferrer"
                            className="text-gray-300 hover:text-white transition-colors duration-200 flex items-center"
                          >
                            <span className="w-1.5 h-1.5 bg-[#2f1c8c] rounded-full mr-2"></span>
                            Careers
                          </a>
                        </li>
                        <li>
                          <a 
                            href="https://www.linkedin.com/company/finlogistics/posts" 
                            target="_blank" 
                            rel="noopener noreferrer"
                            className="text-gray-300 hover:text-white transition-colors duration-200 flex items-center"
                          >
                            <span className="w-1.5 h-1.5 bg-[#2f1c8c] rounded-full mr-2"></span>
                            Blog
                          </a>
                        </li>
                      </ul>
                    </div>
                  </div>
                </div>
              </div>
              <div className="border-t border-gray-800 mt-12 pt-8 flex flex-col md:flex-row items-center justify-between">
                <span className="text-gray-400 text-sm mb-4 md:mb-0">© {new Date().getFullYear()} Fin Mile Logistics Inc and Fin Mile Logistics Limited. All rights reserved.</span>
                <div className="flex space-x-6">
                  <Link to="/privacy-policy" className="text-gray-400 hover:text-white text-sm transition-colors duration-200">
                    Privacy Policy
                  </Link>
                  <Link to="/terms" className="text-gray-400 hover:text-white text-sm transition-colors duration-200">
                    Terms of Service
                  </Link>
                  <Link to="/sitemap" className="text-gray-400 hover:text-white text-sm transition-colors duration-200">
                    Sitemap
                  </Link>
                </div>
              </div>
            </div>
          </footer>
        </div>
      </div>
    </Router>
  );
}

export default App;